@@ -19,7 +19,11 @@ def byte_format(num):
   return "%.3f%s" % (num, 'GB')
 
 # Ignore SIGPIPE
-signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+try:
+  signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+except AttributeError:
+  #OS=windows
+  pass
 
 option_parser = optparse.OptionParser(
     usage='''%prog path timePerPoint:timeToStore [timePerPoint:timeToStore]*
@@ -38,6 +42,8 @@ option_parser.add_option('--aggregationMethod', default='average',
         ', '.join(whisper.aggregationMethods))
 option_parser.add_option('--overwrite', default=False, action='store_true')
 option_parser.add_option('--estimate', default=False, action='store_true', help="Don't create a whisper file, estimate storage requirements based on archive definitions")
+option_parser.add_option('--sparse', default=False, action='store_true', help="Create new whisper as sparse file")
+option_parser.add_option('--fallocate', default=False, action='store_true', help="Create new whisper and use fallocate")
 
 (options, args) = option_parser.parse_args()
 
@@ -51,19 +57,19 @@ if options.estimate:
   archives = 0
   total_points = 0
   for (precision, points) in map(whisper.parseRetentionDef, args):
-    print "Archive %s: %s points of %ss precision" % (archives, points, precision)
+    print("Archive %s: %s points of %ss precision" % (archives, points, precision))
     archives += 1
     total_points += points
 
   size = 16 + (archives * 12) + (total_points * 12)
   disk_size = int(math.ceil(size / 4096.0) * 4096)
-  print "\nEstimated Whisper DB Size: %s (%s bytes on disk with 4k blocks)\n" % (byte_format(size), disk_size)
+  print("\nEstimated Whisper DB Size: %s (%s bytes on disk with 4k blocks)\n" % (byte_format(size), disk_size))
   for x in [1, 5, 10, 50, 100, 500]:
-    print "Estimated storage requirement for %sk metrics: %s" % (x, byte_format(x * 1000 * disk_size))
+    print("Estimated storage requirement for %sk metrics: %s" % (x, byte_format(x * 1000 * disk_size)))
   sys.exit(0)
 
 if len(args) < 2:
-  option_parser.print_usage()
+  option_parser.print_help()
   sys.exit(1)
 
 path = args[0]
@@ -71,13 +77,13 @@ archives = [whisper.parseRetentionDef(retentionDef)
             for retentionDef in args[1:]]
 
 if os.path.exists(path) and options.overwrite:
-    print 'Overwriting existing file: %s' % path
-    os.unlink(path)
+  print('Overwriting existing file: %s' % path)
+  os.unlink(path)
 
 try:
-  whisper.create(path, archives, xFilesFactor=options.xFilesFactor, aggregationMethod=options.aggregationMethod)
-except whisper.WhisperException, exc:
+  whisper.create(path, archives, xFilesFactor=options.xFilesFactor, aggregationMethod=options.aggregationMethod, sparse=options.sparse, useFallocate=options.fallocate)
+except whisper.WhisperException as exc:
   raise SystemExit('[ERROR] %s' % str(exc))
 
 size = os.stat(path).st_size
-print 'Created: %s (%d bytes)' % (path,size)
+print('Created: %s (%d bytes)' % (path,size))
