@@ -21,7 +21,7 @@ option_parser = optparse.OptionParser(
 (options, args) = option_parser.parse_args()
 
 if len(args) < 2:
-  option_parser.print_usage()
+  option_parser.print_help()
   sys.exit(1)
 
 path = args[0]
@@ -36,5 +36,5 @@ try:
     whisper.update(path, value, timestamp)
   else:
     whisper.update_many(path, datapoints)
-except whisper.WhisperException, exc:
+except whisper.WhisperException as exc:
   raise SystemExit('[ERROR] %s' % str(exc))
